From: Michael Hunold <hunold@convergence.de>
To: Linus Torvalds <torvalds@osdl.org>
Cc: colin@colino.net, linux-kernel@vger.kernel.org,
Andrew Morton <akpm@osdl.org>
Subject: Re: [PATCH] fix saa7146 compilation on 2.6.8-rc1
Date: Mon, 12 Jul 2004 21:47:05 +0200 [thread overview]
Message-ID: <40F2EAB9.2010908@convergence.de> (raw)
In-Reply-To: <20040712082545.GA416@jack.colino.net>
[-- Attachment #1: Type: text/plain, Size: 477 bytes --]
Hello Linus, Andrew,
On 07/12/04 10:25, colin@colino.net wrote:
> this patch fixes a compilation error on 2.6.8-rc1. Here's the error:
> drivers/media/common/saa7146_video.c:3: conflicting types for `memory'
> include/asm-m68k/setup.h:365: previous declaration of `memory'
> make[3]: *** [drivers/media/common/saa7146_video.o] Error 1
Colin's patch is fine, an updated version of the patch with an
additional signed-off line is attached.
Please apply. Thanks!
CU
Michael.
[-- Attachment #2: saa7146-memory-variable.diff --]
[-- Type: text/plain, Size: 1107 bytes --]
Signed-off-by: Colin Leroy <colin@colino.net>
Signed-off-by: Michael Hunold <hunold@linuxtv.org>
--- a/drivers/media/common/saa7146_video.c 2004-07-12 10:15:51.833352344 +0200
+++ b/drivers/media/common/saa7146_video.c 2004-07-12 10:16:21.209886432 +0200
@@ -1,9 +1,9 @@
#include <media/saa7146_vv.h>
-static int memory = 32;
+static int max_memory = 32;
-MODULE_PARM(memory,"i");
-MODULE_PARM_DESC(memory, "maximum memory usage for capture buffers (default: 32Mb)");
+MODULE_PARM(max_memory,"i");
+MODULE_PARM_DESC(max_memory, "maximum memory usage for capture buffers (default: 32Mb)");
#define IS_CAPTURE_ACTIVE(fh) \
(((vv->video_status & STATUS_CAPTURE) != 0) && (vv->video_fh == fh))
@@ -1331,9 +1331,9 @@
*size = fh->video_fmt.sizeimage;
- /* check if we exceed the "memory" parameter */
- if( (*count * *size) > (memory*1048576) ) {
- *count = (memory*1048576) / *size;
+ /* check if we exceed the "max_memory" parameter */
+ if( (*count * *size) > (max_memory*1048576) ) {
+ *count = (max_memory*1048576) / *size;
}
DEB_CAP(("%d buffers, %d bytes each.\n",*count,*size));
prev parent reply other threads:[~2004-07-12 19:47 UTC|newest]
Thread overview: 5+ messages / expand[flat|nested] mbox.gz Atom feed top
2004-07-12 8:25 [PATCH] fix saa7146 compilation on 2.6.8-rc1 colin
2004-07-12 15:20 ` Geert Uytterhoeven
2004-07-12 15:31 ` Colin LEROY
2004-07-12 15:40 ` Geert Uytterhoeven
2004-07-12 19:47 ` Michael Hunold [this message]
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=40F2EAB9.2010908@convergence.de \
--to=hunold@convergence.de \
--cc=akpm@osdl.org \
--cc=colin@colino.net \
--cc=linux-kernel@vger.kernel.org \
--cc=torvalds@osdl.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox